@@ -26,8 +26,8 @@
  *   that compiling, linking, and/or using OpenSSL is allowed.
  *   
  *   
- *   $Rev: 151 $
- *   $Date: 2009-07-28 16:04:57 +0200 (Tue, 28 Jul 2009) $
+ *   $Rev: 155 $
+ *   $Date: 2012-04-26 15:41:09 +0200 (Thu, 26 Apr 2012) $
  *   
  *   
 */
@@ -60,7 +60,7 @@ struct timeval tm_main_total;
 fsm_t *fsm = 0;
 /*-------------------------------------------------------------------------*/
 void usage() {
-  printf("ophcrack 3.3.1 by Objectif Securite (http://www.objectif-securite.ch)\n\n");
+  printf("ophcrack 3.4.0 by Objectif Securite (http://www.objectif-securite.ch)\n\n");
   printf("Usage: ophcrack [OPTIONS]\n");
   printf("Cracks Windows passwords with Rainbow tables\n\n");
   printf("  -a              disable audit mode (default)\n");
@@ -663,13 +663,14 @@ void handle_messages(ophcrack_t *crack) {
     
     if (ofile) {
       pthread_mutex_lock(mutex);
-      if (xfile)
+      if (xfile) {
 	ophcrack_export_csv(crack, xfile, fields, ';', 0);
+	fclose(xfile);
+      }
       ophcrack_save(crack, ofile, 0, 0);
       pthread_mutex_unlock(mutex);
       
       fclose(ofile);
-      fclose(xfile);
     }
   }
 
@@ -850,11 +851,24 @@ int main(int argc, char **argv) {
     
     if (ofile == 0) {
       fprintf(stderr, "Cannot open file %s for writing.\n", arg->ofname);
-      exit(1);
+      exit(1); 
     } else
       fclose(ofile);
   }
 
+  // If we are in command line mode, then we check that the csv
+  // file is writable.
+
+  if (!arg->use_gui && arg->exportcsv) {
+    FILE *xfile = fopen(arg->xfname, "w");
+    
+    if (xfile == 0) {
+      fprintf(stderr, "Cannot open file %s for writing.\n", arg->xfname);
+      exit(1); 
+    } else
+      fclose(xfile);
+  }
+
   // If the session auto-saving is enabled, then we check that the
   // session file is writable.
 
@@ -1022,6 +1036,28 @@ int main(int argc, char **argv) {
   // Close the log file.
 
   if (arg->lfile != stdout) fclose(arg->lfile);
+
+
+  /* Save the passwords to the output and csv files. */
+
+  if (!arg->use_gui && arg->ofname) {
+    FILE *ofile = fopen(arg->ofname, "w");
+    FILE *xfile = 0;
+    if (arg->exportcsv)
+      xfile = fopen(arg->xfname, "w");
+    
+    int fields[] = {1,1,1,1,1,1,1,1,1,1,1,1,1};
+    
+    if (ofile) {
+      if (xfile) {
+	ophcrack_export_csv(crack, xfile, fields, ';', 0);
+	fclose(xfile);
+      }
+      ophcrack_save(crack, ofile, 0, 0);
+      fclose(ofile);
+    }
+  }
+
     
   return 0;
 }
