@@ -26,8 +26,8 @@
  *   that compiling, linking, and/or using OpenSSL is allowed.
  *   
  *   
- *   $Rev: 151 $
- *   $Date: 2009-07-28 16:04:57 +0200 (Tue, 28 Jul 2009) $
+ *   $Rev: 155 $
+ *   $Date: 2012-04-26 15:41:09 +0200 (Thu, 26 Apr 2012) $
  *   
  *   
 */
@@ -53,6 +53,8 @@
 #include "nteight.h"
 #include "ntnum.h"
 #include "ntseven.h"
+#include "lmflash.h"
+#include "nteightxl.h"
 #include "message.h"
 /*-------------------------------------------------------------------------*/
 ophcrack_t *ophcrack_alloc(int nthreads, arg_t *arg) {
@@ -146,6 +148,14 @@ int ophcrack_setup_table(table_t *tbl) {
     ret = ntseven_setup(tbl);
     break;
 
+  case lmflash:
+    ret = lmflash_setup(tbl);
+    break;
+
+  case nteightxl:
+    ret = nteightxl_setup(tbl);
+    break;
+
   case unknown:
     ret = -1;
     break;
